@@ -129,7 +129,7 @@ API Reference
 --------------
 """  # noqa: D400
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -170,7 +170,7 @@ from sphinx.environment import BuildEnvironment
 from sphinx.util.docutils import SphinxDirective
 
 # this package
-from sphinx_toolbox.utils import OptionSpec, Purger, SphinxExtMetadata, flag
+from sphinx_toolbox.utils import OptionSpec, Purger, SphinxExtMetadata, flag, metadata_add_version
 
 __all__ = [
 		"InstallationDirective",
@@ -187,7 +187,25 @@ __all__ = [
 		"setup",
 		]
 
-installation_node_purger = Purger("all_installation_node_nodes")
+
+class _Purger(Purger):
+
+	def purge_nodes(self, app: Sphinx, env: BuildEnvironment, docname: str) -> None:  # pragma: no cover
+		"""
+		Remove all redundant nodes.
+
+		:param app: The Sphinx app.
+		:param env: The Sphinx build environment.
+		:param docname: The name of the document to remove nodes for.
+		"""
+
+		if not hasattr(env, self.attr_name):
+			return
+
+		setattr(env, self.attr_name, [])
+
+
+installation_node_purger = _Purger("all_installation_node_nodes")
 extensions_node_purger = Purger("all_extensions_node_nodes")
 
 
@@ -197,13 +215,15 @@ class Sources(List[Tuple[str, str, Callable, Callable, Optional[Dict[str, Callab
 
 	The syntax of each entry is:
 
-	``(option_name, source_name, getter_function, validator_function, extra_options)``
+	.. code-block:: python
 
-	* a string to use in the directive to specify the source to use,
-	* a string to use in the tabs to indicate the installation source,
-	* the function that returns the installation instructions,
-	* a function to validate the option value provided by the user,
-	* a mapping of additional options for the directive that are used by the getter_function.
+		(option_name, source_name, getter_function, validator_function, extra_options)
+
+	* ``option_name`` -- a string to use in the directive to specify the source to use,
+	* ``source_name`` -- a string to use in the tabs to indicate the installation source,
+	* ``getter_function`` -- the function that returns the installation instructions,
+	* ``validator_function`` -- a function to validate the option value provided by the user,
+	* ``extra_options`` -- a mapping of additional options for the directive that are used by the getter_function.
 	"""
 
 	def __init__(self, *args, **kwargs):
@@ -358,7 +378,10 @@ def github_installation(
 	"""
 
 	if "sphinx_toolbox.github" not in env.app.extensions:
-		raise ValueError("The 'sphinx_toolbox.github' is required for the :github: option but it is not enabled!")
+		raise ValueError(
+				"The 'sphinx_toolbox.github' extension is required for the "
+				":github: option but it is not enabled!"
+				)
 
 	username = getattr(env.config, "github_username", None)
 	if username is None:
@@ -415,9 +438,6 @@ class InstallationDirective(SphinxDirective):
 		Generate output for ``HTML`` builders.
 		"""
 
-		if self.arguments:
-			self.options["project_name"] = self.arguments[0]
-
 		targetid = f'installation-{self.env.new_serialno("sphinx-toolbox installation"):d}'
 		targetnode = nodes.target('', '', ids=[targetid])
 
@@ -438,9 +458,6 @@ class InstallationDirective(SphinxDirective):
 		targetid = f'installation-{self.env.new_serialno("sphinx-toolbox installation"):d}'
 		targetnode = nodes.target('', '', ids=[targetid])
 
-		if self.arguments:
-			self.options["project_name"] = self.arguments[0]
-
 		tabs: Dict[str, List[str]] = _get_installation_instructions(self.options, self.env)
 
 		if not tabs:
@@ -469,6 +486,9 @@ class InstallationDirective(SphinxDirective):
 		Create the installation node.
 		"""
 
+		if self.arguments:
+			self.options["project_name"] = self.arguments[0]
+
 		if self.env.app.builder.format.lower() == "html":
 			return self.run_html()
 		else:
@@ -560,7 +580,7 @@ class ExtensionsDirective(SphinxDirective):
 				)
 		bottom_text = (
 				"For more information see "
-				"https://www.sphinx-doc.org/en/master/usage/extensions/index.html#third-party-extensions ."
+				"https://www.sphinx-doc.org/en/master/usage/extensions#third-party-extensions ."
 				)
 
 		if "no-preamble" in self.options:
@@ -583,10 +603,8 @@ class ExtensionsDirective(SphinxDirective):
 		if "no-postamble" not in self.options:
 			content.extend([bottom_text, ''])
 
-		view = ViewList(content)
-
 		extensions_node = nodes.paragraph(rawsource=content)  # type: ignore
-		self.state.nested_parse(view, self.content_offset, extensions_node)  # type: ignore
+		self.state.nested_parse(ViewList(content), self.content_offset, extensions_node)  # type: ignore
 		extensions_node_purger.add_node(self.env, extensions_node, targetnode, self.lineno)
 
 		return [targetnode, extensions_node]
@@ -655,17 +673,15 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 			])
 
 
+@metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.installation`.
 
-	:param app: The Sphinx app.
-
 	.. versionadded:: 0.7.0
-	"""
 
-	# this package
-	from sphinx_toolbox import __version__
+	:param app: The Sphinx app.
+	"""
 
 	if "sphinx_inline_tabs" not in getattr(app, "extensions", ()):
 		app.setup_extension("sphinx_tabs.tabs")
@@ -676,7 +692,8 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 
 	# Instructions for installing a python package
 	app.add_directive("installation", InstallationDirective)
-	app.connect("env-purge-doc", installation_node_purger.purge_nodes)
+	app.connect("env-get-outdated", installation_node_purger.get_outdated_docnames)
+	# app.connect("env-purge-doc", installation_node_purger.purge_nodes)
 
 	# Instructions for enabling a sphinx extension
 	app.add_directive("extensions", ExtensionsDirective)
@@ -687,7 +704,4 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.add_js_file("sphinx_toolbox_installation.js")
 	app.connect("build-finished", copy_asset_files)
 
-	return {
-			"version": __version__,
-			"parallel_read_safe": True,
-			}
+	return {"parallel_read_safe": True}
