@@ -75,12 +75,14 @@ API Reference
 #
 
 # stdlib
+import re
 from inspect import Parameter, Signature
 from typing import TYPE_CHECKING, Any, Dict, List
 
 # 3rd party
 from domdf_python_tools.stringlist import StringList
 from sphinx.application import Sphinx
+from sphinx.config import ENUM
 from sphinx.ext import autodoc
 from sphinx.ext.autodoc.directive import DocumenterBridge
 from sphinx.util import inspect
@@ -104,6 +106,8 @@ __all__ = [
 		"setup",
 		]
 
+_return_type_re = re.compile("^:(rtype|return(s)?):")
+
 
 class OverloadMixin(_OverloadMixinBase):
 	"""
@@ -210,8 +214,6 @@ class OverloadMixin(_OverloadMixinBase):
 
 		if self.env.config.overloads_location == "bottom":
 
-			insert_index = -1
-
 			def process_docstring(
 					app: Sphinx,
 					what: str,
@@ -221,23 +223,39 @@ class OverloadMixin(_OverloadMixinBase):
 					lines: List[str],
 					) -> None:
 
-				nonlocal insert_index
-
 				if callable(obj):
+					seen_return = False
+
+					n_lines = len(lines)
+
 					for i, line in enumerate(lines):
-						if line.startswith(":rtype:"):
-							insert_index = i - len(lines) + 1
+						if not line:
+							continue
+
+						if line[0].isspace():
+							continue
+
+						if _return_type_re.match(line):
+							seen_return = True
+							continue
+
+						if seen_return and i != n_lines:
+							lines.insert(i, '')
+							for inner_line in reversed(self.create_body_overloads()):
+								lines.insert(i, inner_line)
+							lines.insert(i, '')
+
 							break
+					else:
+						lines.append('')
+						lines.extend(self.create_body_overloads())
+						lines.append('')
 
-						elif line.startswith(":return:") or line.startswith(":returns:"):
-							insert_index = i - len(lines)
-
-			listener_id = self.env.app.connect("autodoc-process-docstring", process_docstring, priority=300)
-			super().add_content(more_content, no_docstring)
-			self.env.app.disconnect(listener_id)
-
-			for line in self.create_body_overloads():
-				self.directive.result.insert(insert_index, f"{self.indent}{line}", self.get_sourcename())
+			listener_id = self.env.app.connect("autodoc-process-docstring", process_docstring, priority=600)
+			try:
+				super().add_content(more_content, no_docstring)
+			finally:
+				self.env.app.disconnect(listener_id)
 
 		else:
 			super().add_content(more_content, no_docstring)
@@ -404,13 +422,18 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autodoc.overloads`.
 
-	:param app: The Sphinx app.
-
 	.. versionadded:: 1.4.0
+
+	:param app: The Sphinx app.
 	"""
 
 	app.add_autodocumenter(FunctionDocumenter, override=True)
 	app.add_autodocumenter(MethodDocumenter, override=True)
-	app.add_config_value("overloads_location", "signature", "env")  # top (of body), bottom (of body)
+	app.add_config_value(
+			"overloads_location",
+			"signature",
+			"env",
+			ENUM("top", "bottom", "signature"),  # top (of body), bottom (of body)
+			)
 
 	return {"parallel_read_safe": True}
