@@ -38,8 +38,14 @@ Usage
 		:type: string
 
 		Show this instead of the flags taken from the :class:`~typing.Pattern` object.
+		This should be correctly formatted for insertion into reStructuredText, such as ``:py:data:`re.ASCII```.
 
 
+	.. versionchanged:: 2.7.0
+
+		The flags :py:data:`re.DEBUG` and :py:data:`re.VERBOSE` are now hidden
+		as the don't affect the regex itself.
+
 .. rst:role:: regex
 
 	Formats a regular expression with coloured output.
@@ -281,7 +287,9 @@ class RegexDocumenter(VariableDocumenter):
 				if "flag" in self.options:
 					the_flag = self.options["flag"]
 				else:
-					the_flag = parse_regex_flags(self.object.flags)
+					raw_flags = self.object.flags
+					raw_flags = (raw_flags & ~re.DEBUG) & ~re.VERBOSE
+					the_flag = parse_regex_flags(raw_flags)
 
 				if the_flag:
 					self.add_line(f"     **Flags**, {the_flag}", sourcename)
@@ -334,6 +342,7 @@ def no_formatting(value: Any) -> str:
 
 	Used for unformatted output.
 	"""
+
 	return str(value)
 
 
@@ -444,7 +453,7 @@ class RegexParser:
 						buf.append(type(self).REPEAT_BRACE_COLOUR('{'))
 						buf.append(type(self).REPEAT_COLOUR(str(min_)))
 						buf.append(type(self).LITERAL_COLOUR(','))
-						buf.append(type(self).REPEAT_COLOUR(str(max)))
+						buf.append(type(self).REPEAT_COLOUR(str(max_)))
 						buf.append(type(self).REPEAT_BRACE_COLOUR('}'))
 					if what is MIN_REPEAT:
 						buf.append(type(self).REPEAT_COLOUR('?'))
@@ -494,7 +503,7 @@ class RegexParser:
 					buf.append(type(self).ANY_COLOUR('.'))
 					continue
 
-				print(what, content)
+				print(what, content)  # pragma: no cover
 
 		pattern = regex.pattern.replace('\t', r"\t")
 
@@ -726,7 +735,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.setup_extension("sphinx.ext.autodoc")
 	app.add_autodocumenter(RegexDocumenter)
 
-	roles.register_local_role("regex", Regex())
+	app.add_role("regex", Regex())
 	app.add_node(
 			RegexNode,
 			html=(visit_regex_node, depart_regex_node),
