@@ -118,10 +118,10 @@ import types
 from types import FunctionType, ModuleType
 from typing import Any, AnyStr, Callable, Dict, List, Optional, Tuple, Type, TypeVar, get_type_hints
 
-if sys.version_info < (3, 7, 4):
+if sys.version_info < (3, 7, 4):  # pragma: no cover (py37+)
 	# stdlib
 	from typing import _ForwardRef as ForwardRef  # type: ignore
-else:
+else:  # pragma: no cover (<py37)
 	from typing import ForwardRef  # type: ignore
 
 # 3rd party
@@ -271,7 +271,7 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 	elif annotation is Ellipsis:
 		return "..."
 	elif annotation is itertools.cycle:
-		return ":func:`itertools.cycle`"
+		return f":func:`{prefix}itertools.cycle`"
 	elif annotation is types.GetSetDescriptorType:  # noqa E721
 		return f":py:data:`{prefix}types.GetSetDescriptorType`"
 	elif annotation is types.MemberDescriptorType:  # noqa E721
@@ -284,14 +284,14 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 		return f":py:data:`{prefix}types.ClassMethodDescriptorType`"
 	elif annotation is MethodDescriptorType:  # noqa E721
 		return f":py:data:`{prefix}types.MethodDescriptorType`"
+	elif annotation is types.MethodType:  # noqa E721
+		return f":py:data:`{prefix}types.MethodType`"
 	elif annotation is MethodWrapperType:  # noqa E721
 		return f":py:data:`{prefix}types.MethodWrapperType`"
 	elif annotation is WrapperDescriptorType:  # noqa E721
 		return f":py:data:`{prefix}types.WrapperDescriptorType`"
 	elif annotation is types.BuiltinFunctionType:  # noqa E721
 		return f":py:data:`{prefix}types.BuiltinFunctionType`"
-	elif annotation is types.MethodType:  # noqa E721
-		return f":py:data:`{prefix}types.MethodType`"
 	elif isinstance(annotation, ForwardRef):
 		# Unresolved forward ref
 		return f":py:obj:`{prefix}.{annotation.__forward_arg__}`"
@@ -682,31 +682,6 @@ def process_docstring(
 					lines.insert(insert_index, f":rtype: {formatted_annotation}")
 
 
-@metadata_add_version
-def setup(app: Sphinx) -> SphinxExtMetadata:
-	"""
-	Setup :mod:`sphinx_toolbox.more_autodoc.typehints`.
-
-	:param app: The Sphinx app
-	"""
-
-	if "sphinx_autodoc_typehints" in app.extensions:
-		raise ExtensionError(
-				"'sphinx_toolbox.more_autodoc.typehints' must be loaded before 'sphinx_autodoc_typehints."
-				)
-
-	sphinx_autodoc_typehints.format_annotation = format_annotation
-	sphinx_autodoc_typehints.process_signature = process_signature
-	sphinx_autodoc_typehints.process_docstring = process_docstring
-
-	app.setup_extension("sphinx.ext.autodoc")
-	app.setup_extension("sphinx_autodoc_typehints")
-
-	app.add_config_value("hide_none_rtype", False, "env", [bool])
-
-	return {"parallel_read_safe": True}
-
-
 def _class_get_type_hints(obj, globalns=None, localns=None):
 	"""
 	Return type hints for an object.
@@ -790,3 +765,28 @@ def get_all_type_hints(obj, name, original_obj):
 		rv = obj.__annotations__
 
 	return rv
+
+
+@metadata_add_version
+def setup(app: Sphinx) -> SphinxExtMetadata:
+	"""
+	Setup :mod:`sphinx_toolbox.more_autodoc.typehints`.
+
+	:param app: The Sphinx app
+	"""
+
+	if "sphinx_autodoc_typehints" in app.extensions:
+		raise ExtensionError(
+				"'sphinx_toolbox.more_autodoc.typehints' must be loaded before 'sphinx_autodoc_typehints'."
+				)
+
+	sphinx_autodoc_typehints.format_annotation = format_annotation
+	sphinx_autodoc_typehints.process_signature = process_signature
+	sphinx_autodoc_typehints.process_docstring = process_docstring
+
+	app.setup_extension("sphinx.ext.autodoc")
+	app.setup_extension("sphinx_autodoc_typehints")
+
+	app.add_config_value("hide_none_rtype", False, "env", [bool])
+
+	return {"parallel_read_safe": True}
