@@ -34,7 +34,7 @@ General utility functions.
 # stdlib
 import functools
 import re
-from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional, Pattern, Tuple, Type, TypeVar, cast
+from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional, Pattern, Set, Tuple, Type, TypeVar, cast
 
 # 3rd party
 import sphinx.config
@@ -82,6 +82,8 @@ GITHUB_COM: RequestsURL = RequestsURL("https://github.com")
 #: Type hint for the ``option_spec`` variable of Docutils directives.
 OptionSpec = Mapping[str, Callable[[str], Any]]
 
+_T = TypeVar("_T")
+
 
 @functools.lru_cache()
 def make_github_url(username: str, repository: str) -> RequestsURL:
@@ -129,10 +131,24 @@ class Purger:
 	def __repr__(self) -> str:
 		return f"{self.__class__.__name__}({self.attr_name!r})"
 
-	def purge_nodes(self, app: Sphinx, env: BuildEnvironment, docname: str) -> None:
+	def purge_nodes(  # pragma: no cover
+			self,
+			app: Sphinx,
+			env: BuildEnvironment,
+			docname: str,
+			) -> None:
 		"""
 		Remove all redundant nodes.
 
+		This function can be configured for the :event:`env-purge-doc` event:
+
+		.. code-block::
+
+			my_node_purger = Purger("all_my_node_nodes")
+
+			def setup(app: Sphinx):
+				app.connect("env-purge-doc", my_node_purger.purge_nodes)
+
 		:param app: The Sphinx app.
 		:param env: The Sphinx build environment.
 		:param docname: The name of the document to remove nodes for.
@@ -141,10 +157,42 @@ class Purger:
 		if not hasattr(env, self.attr_name):
 			return
 
-		all_nodes = [
-				todo for todo in getattr(env, self.attr_name) if todo["docname"] != docname
-				]  # pragma: no cover
-		setattr(env, self.attr_name, all_nodes)  # pragma: no cover
+		all_nodes = [todo for todo in getattr(env, self.attr_name) if todo["docname"] != docname]
+		setattr(env, self.attr_name, all_nodes)
+
+	def get_outdated_docnames(
+			self,
+			app: Sphinx,
+			env: BuildEnvironment,
+			added: Set[str],
+			changed: Set[str],
+			removed: Set[str],
+			) -> List[str]:
+		"""
+		Returns a list of all docnames containing one or more nodes this :class:`~.Purger` is aware of.
+
+		This function can be configured for the :event:`env-get-outdated` event:
+
+		.. code-block::
+
+			my_node_purger = Purger("all_my_node_nodes")
+
+			def setup(app: Sphinx):
+				app.connect("env-get-outdated", my_node_purger.get_outdated_docnames)
+
+		.. versionadded:: 2.7.0
+
+		:param app: The Sphinx app.
+		:param env: The Sphinx build environment.
+		:param added: A set of newly added documents.
+		:param changed: A set of document names whose content has changed.
+		:param removed: A set of document names which have been removed.
+		"""
+
+		if not hasattr(env, self.attr_name):
+			return []
+
+		return list({todo["docname"] for todo in getattr(env, self.attr_name)})
 
 	def add_node(self, env: BuildEnvironment, node: Node, targetnode: Node, lineno: int):
 		"""
@@ -208,9 +256,6 @@ class NoMatchError(ValueError):
 	"""
 
 
-_T = TypeVar("_T")
-
-
 def get_first_matching(
 		condition: Callable[[Any], bool],
 		iterable: Iterable[_T],
@@ -401,11 +446,9 @@ def unknown_module_warning(documenter: Documenter) -> None:
 	"""
 	Log a warning that the module to import the object from is unknown.
 
-	:param documenter:
-
-	:rtype:
-
 	.. versionadded:: 0.2.0
+
+	:param documenter:
 	"""
 
 	msg = __(
@@ -508,6 +551,11 @@ def parse_parameters(lines: List[str], tab_size: int = 8) -> Tuple[Dict[str, Par
 			params[param_name] = {"doc": [], "type": ''}
 
 	for line in lines:
+
+		if post_output:
+			post_output.append(line)
+			continue
+
 		typed_m = typed_param_regex.match(line)
 		untyped_m = untyped_param_regex.match(line)
 		type_only_m = typed_flag_regex.match(line)
@@ -541,13 +589,11 @@ def parse_parameters(lines: List[str], tab_size: int = 8) -> Tuple[Dict[str, Par
 
 def is_namedtuple(obj: Any) -> bool:
 	"""
-	Returns whether the given class is a :func:`collections.namedtuple`.
-
-	:param obj:
-
-	:rtype:
+	Returns whether the given object is a :func:`collections.namedtuple` class.
 
 	.. versionadded:: 0.8.0
+
+	:param obj:
 	"""
 
 	return isinstance(obj, type) and issubclass(obj, tuple) and hasattr(obj, "_fields")
@@ -555,18 +601,15 @@ def is_namedtuple(obj: Any) -> bool:
 
 def allow_subclass_add(app: Sphinx, *documenters: Type[Documenter]):
 	"""
-	Add the given autodocumenters, but only if a subclass of it is not
-	already registered.
+	Add the given autodocumenters, but only if a subclass of it is not already registered.
 
 	This allows other libraries to extend the autodocumenters.
 
+	.. versionadded:: 0.8.0
+
 	:param app: The Sphinx app.
 	:param documenters:
-
-	:rtype:
-
-	.. versionadded:: 0.8.0
-	"""  # noqa D400
+	"""
 
 	for cls in documenters:
 		existing_documenter = app.registry.documenters.get(cls.objtype)
@@ -621,7 +664,7 @@ def add_nbsp_substitution(config: sphinx.config.Config):
 	nbsp_sub = ".. |nbsp| unicode:: 0xA0\n   :trim:"
 
 	if not config.rst_prolog:
-		config.rst_prolog = f"\n{nbsp_sub}"  # type: ignore
+		config.rst_prolog = ''  # type: ignore
 
-	elif nbsp_sub not in config.rst_prolog:
+	if nbsp_sub not in config.rst_prolog:
 		config.rst_prolog = '\n'.join([config.rst_prolog, '', nbsp_sub])  # type: ignore
